emacs-diffs
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Emacs-diffs] Changes to emacs/src/term.c,v


From: Dan Nicolaescu
Subject: [Emacs-diffs] Changes to emacs/src/term.c,v
Date: Tue, 04 Sep 2007 15:44:12 +0000

CVSROOT:        /cvsroot/emacs
Module name:    emacs
Changes by:     Dan Nicolaescu <dann>   07/09/04 15:44:11

Index: src/term.c
===================================================================
RCS file: /cvsroot/emacs/emacs/src/term.c,v
retrieving revision 1.192
retrieving revision 1.193
diff -u -b -r1.192 -r1.193
--- src/term.c  29 Aug 2007 21:46:50 -0000      1.192
+++ src/term.c  4 Sep 2007 15:44:08 -0000       1.193
@@ -124,10 +124,10 @@
 extern Lisp_Object Qspace, QCalign_to, QCwidth;
 
 /* Functions to call after suspending a tty. */
-Lisp_Object Vsuspend_tty_functions;
+Lisp_Object Vsuspend_tty_hook;
 
 /* Functions to call after resuming a tty. */
-Lisp_Object Vresume_tty_functions;
+Lisp_Object Vresume_tty_hook;
 
 /* Chain of all tty device parameters. */
 struct tty_display_info *tty_list;
@@ -2229,7 +2229,7 @@
 TTY may be a terminal id, a frame, or nil for the terminal device of
 the currently selected frame.
 
-This function runs `suspend-tty-functions' after suspending the
+This function runs `suspend-tty-hook' after suspending the
 device.  The functions are run with one arg, the id of the suspended
 terminal device.
 
@@ -2264,11 +2264,11 @@
       if (FRAMEP (t->display_info.tty->top_frame))
         FRAME_SET_VISIBLE (XFRAME (t->display_info.tty->top_frame), 0);
       
-      /* Run `suspend-tty-functions'.  */
+      /* Run `suspend-tty-hook'.  */
       if (!NILP (Vrun_hooks))
         {
           Lisp_Object args[2];
-          args[0] = intern ("suspend-tty-functions");
+          args[0] = intern ("suspend-tty-hook");
           args[1] = make_number (t->id);
           Frun_hook_with_args (2, args);
         }
@@ -2288,7 +2288,7 @@
 It is an error to resume a terminal while another terminal is active
 on the same device.
 
-This function runs `resume-tty-functions' after resuming the terminal.
+This function runs `resume-tty-hook' after resuming the terminal.
 The functions are run with one arg, the id of the resumed terminal
 device.
 
@@ -2329,11 +2329,11 @@
 
       init_sys_modes (t->display_info.tty);
 
-      /* Run `suspend-tty-functions'.  */
+      /* Run `resume-tty-hook'.  */
       if (!NILP (Vrun_hooks))
         {
           Lisp_Object args[2];
-          args[0] = intern ("resume-tty-functions");
+          args[0] = intern ("resume-tty-hook");
           args[1] = make_number (t->id);
           Frun_hook_with_args (2, args);
         }
@@ -3871,18 +3871,18 @@
   system_uses_terminfo = 0;
 #endif
 
-  DEFVAR_LISP ("suspend-tty-functions", &Vsuspend_tty_functions,
-    doc: /* Functions to be run after suspending a tty.
+  DEFVAR_LISP ("suspend-tty-hook", &Vsuspend_tty_hook,
+    doc: /* Hook to be run after suspending a tty.
 The functions are run with one argument, the terminal id to be suspended.
 See `suspend-tty'.  */);
-  Vsuspend_tty_functions = Qnil;
+  Vsuspend_tty_hook = Qnil;
 
 
-  DEFVAR_LISP ("resume-tty-functions", &Vresume_tty_functions,
-    doc: /* Functions to be run after resuming a tty.
+  DEFVAR_LISP ("resume-tty-hook", &Vresume_tty_hook,
+    doc: /* Hook to be run after resuming a tty.
 The functions are run with one argument, the terminal id that was revived.
 See `resume-tty'.  */);
-  Vresume_tty_functions = Qnil;
+  Vresume_tty_hook = Qnil;
 
   DEFVAR_BOOL ("visible-cursor", &visible_cursor,
               doc: /* Non-nil means to make the cursor very visible.




reply via email to

[Prev in Thread] Current Thread [Next in Thread]